@@ -14,3 +14,8 @@ class DepartmentForms(forms.Form):
     parent_id = forms.IntegerField()
     organization_id = forms.IntegerField()
 
+
+class MoveDepartmentIndexForms(forms.Form):
+    department_id = forms.IntegerField()
+    type = forms.CharField(min_length=2, max_length=4)
+
