@@ -33,7 +33,7 @@ if __name__ == '__main__':
     #     return res
 
 
-    # obj = DepartmentViewSet(1)
+    obj = DepartmentViewSet(1)
     # print(obj.list("sub", 2))
     # print(obj.list("all"))
     # print(obj.list("all", department_name="o"))
@@ -41,7 +41,7 @@ if __name__ == '__main__':
     # print(obj.retrieve(3))
     # print(obj.update(18, {"name": "前端99", "parent_id": 2, "charger_id": None}))
     # print(obj.delete(2))
-    # print(obj.move_show_order([{"id": 5, "show_order": 5}, {"id": 7, "show_order": 4}]))
+    print(obj.move_show_order({"department_id": 4, "type": "up"}))
     # print(obj.create_department_user(5, [1, 2, 3]))
     # print(obj.department_user_list(5,))
     # print(obj.delete_department_user(5, [11]))
